# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-10-17 14:32
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('djangoldp_project', '0004_auto_20191003_1145'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='member',
            name='is_captain',
        ),
        migrations.AddField(
            model_name='project',
            name='captain',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='project',
            name='team',
            field=models.ManyToManyField(blank=True, through='djangoldp_project.Member', to=settings.AUTH_USER_MODEL),
        ),
    ]
